@@ -9,10 +9,9 @@ API_VERSION = "1.10.2"
 
 import binascii
 import uuid
-
 from flask import request
 from flask import Blueprint
-from pony.orm import ObjectNotFound
+from pony.orm import ObjectNotFound, TransactionIntegrityError
 from pony.orm import commit
 
 from ..db import ClientPrefs, Folder
@@ -24,10 +23,20 @@ from .formatters import JSONFormatter, JSONPFormatter, XMLFormatter
 api = Blueprint("api", __name__)
 
 
+def api_routing(endpoint):
+    def decorator(func):
+        viewendpoint = "{}.view".format(endpoint)
+        api.add_url_rule(endpoint, view_func=func, methods=["GET", "POST"])
+        api.add_url_rule(viewendpoint, view_func=func, methods=["GET", "POST"])
+        return func
+
+    return decorator
+
+
 @api.before_request
 def set_formatter():
     """Return a function to create the response."""
-    f, callback = map(request.values.get, ["f", "callback"])
+    f, callback = map(request.values.get, ("f", "callback"))
     if f == "jsonp":
         request.formatter = JSONPFormatter(callback)
     elif f == "json":
@@ -74,8 +83,15 @@ def get_client_prefs():
     try:
         request.client = ClientPrefs[request.user, client]
     except ObjectNotFound:
-        request.client = ClientPrefs(user=request.user, client_name=client)
-        commit()
+        try:
+            request.client = ClientPrefs(user=request.user, client_name=client)
+            commit()
+        except TransactionIntegrityError:
+            # We might have hit a race condition here, another request already created
+            # the ClientPrefs. Issue #220
+            # Reload the user or Pony will complain about different transactions
+            request.user = UserManager.get(request.user.id)
+            request.client = ClientPrefs[request.user, client]
 
 
 def get_entity(cls, param="id"):
