@@ -7,7 +7,7 @@
 
 from datetime import timedelta
 from flask import request
-from pony.orm import select, desc, avg, max, min, count, between
+from pony.orm import select, desc, avg, max, min, count, between, distinct
 
 from ..db import (
     Folder,
@@ -21,15 +21,15 @@ from ..db import (
 )
 from ..db import now
 
-from . import api
+from . import api_routing
 from .exceptions import GenericError, NotFound
 
 
-@api.route("/getRandomSongs.view", methods=["GET", "POST"])
+@api_routing("/getRandomSongs")
 def rand_songs():
     size = request.values.get("size", "10")
     genre, fromYear, toYear, musicFolderId = map(
-        request.values.get, ["genre", "fromYear", "toYear", "musicFolderId"]
+        request.values.get, ("genre", "fromYear", "toYear", "musicFolderId")
     )
 
     size = int(size) if size else 10
@@ -57,20 +57,20 @@ def rand_songs():
 
     return request.formatter(
         "randomSongs",
-        dict(
-            song=[
+        {
+            "song": [
                 t.as_subsonic_child(request.user, request.client)
                 for t in query.without_distinct().random(size)
             ]
-        ),
+        },
     )
 
 
-@api.route("/getAlbumList.view", methods=["GET", "POST"])
+@api_routing("/getAlbumList")
 def album_list():
     ltype = request.values["type"]
 
-    size, offset = map(request.values.get, ["size", "offset"])
+    size, offset = map(request.values.get, ("size", "offset"))
     size = int(size) if size else 10
     offset = int(offset) if offset else 0
 
@@ -78,12 +78,12 @@ def album_list():
     if ltype == "random":
         return request.formatter(
             "albumList",
-            dict(
-                album=[
+            {
+                "album": [
                     a.as_subsonic_child(request.user)
-                    for a in query.distinct().random(size)
+                    for a in distinct(query.random(size))
                 ]
-            ),
+            },
         )
     elif ltype == "newest":
         query = query.sort_by(desc(Folder.created)).distinct()
@@ -123,17 +123,19 @@ def album_list():
 
     return request.formatter(
         "albumList",
-        dict(
-            album=[f.as_subsonic_child(request.user) for f in query.limit(size, offset)]
-        ),
+        {
+            "album": [
+                f.as_subsonic_child(request.user) for f in query.limit(size, offset)
+            ]
+        },
     )
 
 
-@api.route("/getAlbumList2.view", methods=["GET", "POST"])
+@api_routing("/getAlbumList2")
 def album_list_id3():
     ltype = request.values["type"]
 
-    size, offset = map(request.values.get, ["size", "offset"])
+    size, offset = map(request.values.get, ("size", "offset"))
     size = int(size) if size else 10
     offset = int(offset) if offset else 0
 
@@ -141,7 +143,7 @@ def album_list_id3():
     if ltype == "random":
         return request.formatter(
             "albumList2",
-            dict(album=[a.as_subsonic_album(request.user) for a in query.random(size)]),
+            {"album": [a.as_subsonic_album(request.user) for a in query.random(size)]},
         )
     elif ltype == "newest":
         query = query.order_by(lambda a: desc(min(a.tracks.created)))
@@ -177,28 +179,30 @@ def album_list_id3():
 
     return request.formatter(
         "albumList2",
-        dict(
-            album=[f.as_subsonic_album(request.user) for f in query.limit(size, offset)]
-        ),
+        {
+            "album": [
+                f.as_subsonic_album(request.user) for f in query.limit(size, offset)
+            ]
+        },
     )
 
 
-@api.route("/getSongsByGenre.view", methods=["GET", "POST"])
+@api_routing("/getSongsByGenre")
 def songs_by_genre():
     genre = request.values["genre"]
 
-    count, offset = map(request.values.get, ["count", "offset"])
+    count, offset = map(request.values.get, ("count", "offset"))
     count = int(count) if count else 10
     offset = int(offset) if offset else 0
 
     query = select(t for t in Track if t.genre == genre).limit(count, offset)
     return request.formatter(
         "songsByGenre",
-        dict(song=[t.as_subsonic_child(request.user, request.client) for t in query]),
+        {"song": [t.as_subsonic_child(request.user, request.client) for t in query]},
     )
 
 
-@api.route("/getNowPlaying.view", methods=["GET", "POST"])
+@api_routing("/getNowPlaying")
 def now_playing():
     query = User.select(
         lambda u: u.last_play is not None
@@ -207,67 +211,67 @@ def now_playing():
 
     return request.formatter(
         "nowPlaying",
-        dict(
-            entry=[
-                dict(
-                    u.last_play.as_subsonic_child(request.user, request.client),
-                    username=u.name,
-                    minutesAgo=(now() - u.last_play_date).seconds / 60,
-                    playerId=0,
-                )
+        {
+            "entry": [
+                {
+                    **u.last_play.as_subsonic_child(request.user, request.client),
+                    "username": u.name,
+                    "minutesAgo": (now() - u.last_play_date).seconds / 60,
+                    "playerId": 0,
+                }
                 for u in query
             ]
-        ),
+        },
     )
 
 
-@api.route("/getStarred.view", methods=["GET", "POST"])
+@api_routing("/getStarred")
 def get_starred():
     folders = select(s.starred for s in StarredFolder if s.user.id == request.user.id)
 
     return request.formatter(
         "starred",
-        dict(
-            artist=[
+        {
+            "artist": [
                 sf.as_subsonic_artist(request.user)
                 for sf in folders.filter(lambda f: count(f.tracks) == 0)
             ],
-            album=[
+            "album": [
                 sf.as_subsonic_child(request.user)
                 for sf in folders.filter(lambda f: count(f.tracks) > 0)
             ],
-            song=[
+            "song": [
                 st.as_subsonic_child(request.user, request.client)
                 for st in select(
                     s.starred for s in StarredTrack if s.user.id == request.user.id
                 )
             ],
-        ),
+        },
     )
 
 
-@api.route("/getStarred2.view", methods=["GET", "POST"])
+@api_routing("/getStarred2")
 def get_starred_id3():
     return request.formatter(
         "starred2",
-        dict(
-            artist=[
+        {
+            "artist": [
                 sa.as_subsonic_artist(request.user)
                 for sa in select(
                     s.starred for s in StarredArtist if s.user.id == request.user.id
                 )
             ],
-            album=[
+            "album": [
                 sa.as_subsonic_album(request.user)
                 for sa in select(
                     s.starred for s in StarredAlbum if s.user.id == request.user.id
                 )
             ],
-            song=[
+            "song": [
                 st.as_subsonic_child(request.user, request.client)
                 for st in select(
                     s.starred for s in StarredTrack if s.user.id == request.user.id
                 )
             ],
-        ),
+        },
     )
