@@ -16,7 +16,7 @@ from ..db import StarredTrack, StarredAlbum, StarredArtist, StarredFolder
 from ..db import RatingTrack, RatingFolder
 from ..lastfm import LastFm
 
-from . import api, get_entity, get_entity_id
+from . import get_entity, get_entity_id, api_routing
 from .exceptions import AggregateException, GenericError, MissingParameter, NotFound
 
 
@@ -51,11 +51,10 @@ def unstar_single(cls, starcls, eid):
     """
 
     delete(s for s in starcls if s.user.id == request.user.id and s.starred.id == eid)
-    return None
 
 
 def handle_star_request(func):
-    id, albumId, artistId = map(request.values.getlist, ["id", "albumId", "artistId"])
+    id, albumId, artistId = map(request.values.getlist, ("id", "albumId", "artistId"))
 
     if not id and not albumId and not artistId:
         raise MissingParameter("id, albumId or artistId")
@@ -108,17 +107,17 @@ def handle_star_request(func):
     return request.formatter.empty
 
 
-@api.route("/star.view", methods=["GET", "POST"])
+@api_routing("/star")
 def star():
     return handle_star_request(star_single)
 
 
-@api.route("/unstar.view", methods=["GET", "POST"])
+@api_routing("/unstar")
 def unstar():
     return handle_star_request(unstar_single)
 
 
-@api.route("/setRating.view", methods=["GET", "POST"])
+@api_routing("/setRating")
 def rate():
     id = request.values["id"]
     rating = request.values["rating"]
@@ -172,10 +171,10 @@ def rate():
     return request.formatter.empty
 
 
-@api.route("/scrobble.view", methods=["GET", "POST"])
+@api_routing("/scrobble")
 def scrobble():
     res = get_entity(Track)
-    t, submission = map(request.values.get, ["time", "submission"])
+    t, submission = map(request.values.get, ("time", "submission"))
     t = int(t) / 1000 if t else int(time.time())
 
     lfm = LastFm(current_app.config["LASTFM"], request.user)
