@@ -8,10 +8,10 @@
 from flask import request
 
 from ..db import ChatMessage
-from . import api
+from . import api_routing
 
 
-@api.route("/getChatMessages.view", methods=["GET", "POST"])
+@api_routing("/getChatMessages")
 def get_chat():
     since = request.values.get("since")
     since = int(since) / 1000 if since else None
@@ -21,11 +21,11 @@ def get_chat():
         query = query.filter(lambda m: m.time > since)
 
     return request.formatter(
-        "chatMessages", dict(chatMessage=[msg.responsize() for msg in query])
+        "chatMessages", {"chatMessage": [msg.responsize() for msg in query]}
     )
 
 
-@api.route("/addChatMessage.view", methods=["GET", "POST"])
+@api_routing("/addChatMessage")
 def add_chat_message():
     msg = request.values["message"]
     ChatMessage(user=request.user, message=msg)
