@@ -14,11 +14,11 @@ from ..daemon import DaemonClient
 from ..daemon.exceptions import DaemonUnavailableError
 from ..db import Track
 
-from . import api
+from . import api_routing
 from .exceptions import GenericError, MissingParameter, Forbidden
 
 
-@api.route("/jukeboxControl.view", methods=["GET", "POST"])
+@api_routing("/jukeboxControl")
 def jukebox_control():
     if not request.user.jukebox and not request.user.admin:
         raise Forbidden()
@@ -79,12 +79,12 @@ def jukebox_control():
     except DaemonUnavailableError:
         raise GenericError("Jukebox unavaliable")
 
-    rv = dict(
-        currentIndex=status.index,
-        playing=status.playing,
-        gain=status.gain,
-        position=status.position,
-    )
+    rv = {
+        "currentIndex": status.index,
+        "playing": status.playing,
+        "gain": status.gain,
+        "position": status.position,
+    }
     if action == "get":
         playlist = []
         for path in status.playlist:
