@@ -22,13 +22,13 @@ from flask import current_app
 from PIL import Image
 from pony.orm import ObjectNotFound
 from xml.etree import ElementTree
-from zipfile import ZIP_DEFLATED
-from zipstream import ZipFile
+from zipstream import ZipStream
 
 from ..cache import CacheMiss
 from ..db import Track, Album, Folder, now
+from ..covers import EXTENSIONS
 
-from . import api, get_entity, get_entity_id
+from . import get_entity, get_entity_id, api_routing
 from .exceptions import (
     GenericError,
     NotFound,
@@ -63,7 +63,7 @@ def prepare_transcoding_cmdline(
     return ret
 
 
-@api.route("/stream.view", methods=["GET", "POST"])
+@api_routing("/stream")
 def stream_media():
     res = get_entity(Track)
 
@@ -73,7 +73,7 @@ def stream_media():
         raise UnsupportedParameter("size")
 
     maxBitRate, request_format, estimateContentLength = map(
-        request.values.get, ["maxBitRate", "format", "estimateContentLength"]
+        request.values.get, ("maxBitRate", "format", "estimateContentLength")
     )
     if request_format:
         request_format = request_format.lower()
@@ -218,7 +218,7 @@ def stream_media():
     return response
 
 
-@api.route("/download.view", methods=["GET", "POST"])
+@api_routing("/download")
 def download_media():
     id = request.values["id"]
 
@@ -249,15 +249,75 @@ def download_media():
         except ObjectNotFound:
             raise NotFound("Folder")
 
-    z = ZipFile(compression=ZIP_DEFLATED)
-    for track in rv.tracks:
-        z.write(track.path, os.path.basename(track.path))
+    # Stream a zip of multiple files to the client
+    z = ZipStream(sized=True)
+    if isinstance(rv, Folder):
+        # Add the entire folder tree to the zip
+        z.add_path(rv.path, recurse=True)
+    else:
+        # Add tracks + cover art to the zip
+        for track in rv.tracks:
+            z.add_path(track.path)
+
+        cover_path = _cover_from_collection(rv, extract=False)
+        if cover_path:
+            z.add_path(cover_path)
+
+    if not z:
+        raise GenericError("Nothing to download")
+
     resp = Response(z, mimetype="application/zip")
     resp.headers["Content-Disposition"] = "attachment; filename={}.zip".format(rv.name)
+    resp.headers["Content-Length"] = len(z)
     return resp
 
 
-@api.route("/getCoverArt.view", methods=["GET", "POST"])
+def _cover_from_track(tid):
+    """Extract and return a path to a track's cover art
+
+    Returns None if no cover art is available.
+    """
+    cache = current_app.cache
+    cache_key = "{}-cover".format(tid)
+    try:
+        return cache.get(cache_key)
+    except CacheMiss:
+        obj = Track[tid]
+        try:
+            return cache.set(cache_key, mediafile.MediaFile(obj.path).art)
+        except mediafile.UnreadableFileError:
+            return None
+
+
+def _cover_from_collection(obj, extract=True):
+    """Get a path to cover art from a collection (Album, Folder)
+
+    If `extract` is True, will fall back to extracting cover art from tracks
+    Returns None if no cover art is available.
+    """
+    cover_path = None
+
+    if isinstance(obj, Folder) and obj.cover_art:
+        cover_path = os.path.join(obj.path, obj.cover_art)
+
+    elif isinstance(obj, Album):
+        track_with_folder_cover = obj.tracks.select(
+            lambda t: t.folder.cover_art is not None
+        ).first()
+        if track_with_folder_cover is not None:
+            cover_path = _cover_from_collection(track_with_folder_cover.folder)
+
+        if not cover_path and extract:
+            track_with_embedded = obj.tracks.select(lambda t: t.has_art).first()
+            if track_with_embedded is not None:
+                cover_path = _cover_from_track(track_with_embedded.id)
+
+    if not cover_path or not os.path.isfile(cover_path):
+        return None
+    return cover_path
+
+
+@api_routing("/getCoverArt")
 def cover_art():
     cache = current_app.cache
 
@@ -267,39 +327,38 @@ def cover_art():
     except GenericError:
         fid = None
     try:
-        tid = get_entity_id(Track, eid)
+        uid = get_entity_id(Track, eid)
     except GenericError:
-        tid = None
+        uid = None
 
-    if not fid and not tid:
+    if not fid and not uid:
         raise GenericError("Invalid ID")
 
+    cover_path = None
     if fid and Folder.exists(id=eid):
-        res = get_entity(Folder)
-        if not res.cover_art or not os.path.isfile(
-            os.path.join(res.path, res.cover_art)
-        ):
-            raise NotFound("Cover art")
-        cover_path = os.path.join(res.path, res.cover_art)
-    elif tid and Track.exists(id=eid):
-        cache_key = "{}-cover".format(eid)
-        try:
-            cover_path = cache.get(cache_key)
-        except CacheMiss:
-            res = get_entity(Track)
-            try:
-                art = mediafile.MediaFile(res.path).art
-            except mediafile.UnreadableFileError:
-                raise NotFound("Cover art")
-            cover_path = cache.set(cache_key, art)
+        cover_path = _cover_from_collection(get_entity(Folder))
+    elif uid and Track.exists(id=eid):
+        cover_path = _cover_from_track(eid)
+    elif uid and Album.exists(id=uid):
+        cover_path = _cover_from_collection(get_entity(Album))
     else:
         raise NotFound("Entity")
 
+    if not cover_path:
+        raise NotFound("Cover art")
+
     size = request.values.get("size")
     if size:
         size = int(size)
     else:
-        return send_file(cover_path)
+        # If the cover was extracted from a track it won't have an accurate
+        # extension for Flask to derive the mimetype from - derive it from the
+        # contents instead.
+        mimetype = None
+        if uid and os.path.splitext(cover_path)[1].lower() not in EXTENSIONS:
+            with Image.open(cover_path) as im:
+                mimetype = "image/{}".format(im.format.lower())
+        return send_file(cover_path, mimetype=mimetype)
 
     with Image.open(cover_path) as im:
         mimetype = "image/{}".format(im.format.lower())
@@ -316,13 +375,29 @@ def cover_art():
             return send_file(cache.get(cache_key), mimetype=mimetype)
 
 
-@api.route("/getLyrics.view", methods=["GET", "POST"])
+def lyrics_response_for_track(track, lyrics):
+    return request.formatter(
+        "lyrics",
+        {"artist": track.album.artist.name, "title": track.title, "value": lyrics},
+    )
+
+
+@api_routing("/getLyrics")
 def lyrics():
     artist = request.values["artist"]
     title = request.values["title"]
 
     query = Track.select(lambda t: title in t.title and artist in t.artist.name)
     for track in query:
+        # Read from track metadata
+        lyrics = mediafile.MediaFile(track.path).lyrics
+        if lyrics is not None:
+            lyrics = lyrics.replace("\x00", "").strip()
+            if lyrics:
+                logger.debug("Found lyrics in file metadata: " + track.path)
+                return lyrics_response_for_track(track, lyrics)
+
+        # Look for a text file with the same name of the track
         lyrics_path = os.path.splitext(track.path)[0] + ".txt"
         if os.path.exists(lyrics_path):
             logger.debug("Found lyrics file: " + lyrics_path)
@@ -331,15 +406,12 @@ def lyrics():
                 with open(lyrics_path) as f:
                     lyrics = f.read()
             except UnicodeError:
-                # Lyrics file couldn't be decoded. Rather than displaying an error, try with the potential next files or
-                # return no lyrics. Log it anyway.
+                # Lyrics file couldn't be decoded. Rather than displaying an error, try
+                # with the potential next files or return no lyrics. Log it anyway.
                 logger.warning("Unsupported encoding for lyrics file " + lyrics_path)
                 continue
 
-            return request.formatter(
-                "lyrics",
-                dict(artist=track.album.artist.name, title=track.title, value=lyrics),
-            )
+            return lyrics_response_for_track(track, lyrics)
 
     # Create a stable, unique, filesystem-compatible identifier for the artist+title
     unique = hashlib.md5(
@@ -347,7 +419,7 @@ def lyrics():
     ).hexdigest()
     cache_key = "lyrics-{}".format(unique)
 
-    lyrics = dict()
+    lyrics = {}
     try:
         lyrics = json.loads(
             zlib.decompress(current_app.cache.get_value(cache_key)).decode("utf-8")
@@ -362,11 +434,11 @@ def lyrics():
             root = ElementTree.fromstring(r.content)
 
             ns = {"cl": "http://api.chartlyrics.com/"}
-            lyrics = dict(
-                artist=root.find("cl:LyricArtist", namespaces=ns).text,
-                title=root.find("cl:LyricSong", namespaces=ns).text,
-                value=root.find("cl:Lyric", namespaces=ns).text,
-            )
+            lyrics = {
+                "artist": root.find("cl:LyricArtist", namespaces=ns).text,
+                "title": root.find("cl:LyricSong", namespaces=ns).text,
+                "value": root.find("cl:Lyric", namespaces=ns).text,
+            }
 
             current_app.cache.set(
                 cache_key, zlib.compress(json.dumps(lyrics).encode("utf-8"), 9)
