@@ -393,16 +393,19 @@ class Scanner(Thread):
         children = []
         drive, _ = os.path.splitdrive(path)
         path = os.path.dirname(path)
-        while path != drive and path != "/":
+        while path not in (drive, "/"):
             folder = Folder.get(path=path)
             if folder is not None:
                 break
 
             created = datetime.fromtimestamp(os.path.getmtime(path))
             children.append(
-                dict(
-                    root=False, name=os.path.basename(path), path=path, created=created
-                )
+                {
+                    "root": False,
+                    "name": os.path.basename(path),
+                    "path": path,
+                    "created": created,
+                }
             )
             path = os.path.dirname(path)
 
