@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-#
 # This file is part of Supysonic.
 # Supysonic is a Python implementation of the Subsonic server API.
 #
@@ -7,7 +5,7 @@
 #
 # Distributed under terms of the GNU AGPLv3 license.
 
-import uuid
+import unittest
 
 from pony.orm import db_session
 
@@ -21,7 +19,7 @@ class AlbumSongsTestCase(ApiTestBase):
     # Let's just check paramter validation and ensure coverage
 
     def setUp(self):
-        super(AlbumSongsTestCase, self).setUp()
+        super().setUp()
 
         with db_session:
             folder = Folder(name="Root", root=True, path="tests/assets")
