@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-#
 # This file is part of Supysonic.
 # Supysonic is a Python implementation of the Subsonic server API.
 #
@@ -8,9 +6,9 @@
 # Distributed under terms of the GNU AGPLv3 license.
 
 import time
+import unittest
 import uuid
 
-from lxml import etree
 from pony.orm import db_session
 
 from supysonic.db import Folder, Artist, Album, Track
@@ -20,7 +18,7 @@ from .apitestbase import ApiTestBase
 
 class BrowseTestCase(ApiTestBase):
     def setUp(self):
-        super(BrowseTestCase, self).setUp()
+        super().setUp()
 
         with db_session:
             Folder(root=True, name="Empty root", path="/tmp")
@@ -45,7 +43,7 @@ class BrowseTestCase(ApiTestBase):
                     album = Album(name=letter + lether + "lbum", artist=artist)
 
                     for num, song in enumerate(["One", "Two", "Three"]):
-                        track = Track(
+                        Track(
                             disc=1,
                             number=num,
                             title=song,
